@@ -16,7 +16,7 @@ import requests
 
 
 
-def load_ALMA_dic(file_path):
+def load_ALMA_dic():
     """
     Load the ALMA dictionary from a binary pickle file.
 
@@ -35,15 +35,16 @@ def load_ALMA_dic(file_path):
 
     try:
                 # Download the file from the URL
-        data  = requests.get(url)
+        response = requests.get(url)
+        data = response.content
         # Load the data from the file into a Python object
         # data = pickle.loads(response.content)
         # with open(file_path, 'rb') as f:
         #     ALMA_dic = pickle.load(f)
-        ALMA_dic= dict(data)
-        return ALMA_dic
+        my_dict = pickle.loads(data)
+        return my_dict
     except FileNotFoundError as e:
-        print(f"File not found: {file_path}")
+        print(f"File not found: {url}")
         raise e
     except pickle.UnpicklingError as e:
         print("Error while unpickling the data.")
